==> haskell-hasql-transaction-0.5-31-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.5
id: hasql-transaction-0.5-6YrDzCVErhyGmctCGVi0kr
key: hasql-transaction-0.5-6YrDzCVErhyGmctCGVi0kr
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Queries
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
abi: 2c7cc8a06ce4558d5a7e0fc29141b49a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hasql-transaction-0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/hasql-transaction-0.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/hasql-transaction-0.5
hs-libraries: HShasql-transaction-0.5-6YrDzCVErhyGmctCGVi0kr
depends:
    base-4.9.0.0 base-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
    bytestring-0.10.8.1
    bytestring-tree-builder-0.2.7.1-E2ysOXo3HB01TL1PzBXA2X
    contravariant-1.4-BhMeiKXigEF6jqFehOEdeG
    contravariant-extras-0.3.3.1-6JwLhf1IH33AIT8qu08gpr
    hasql-0.19.18-6ecpH6b244v4fQif8qSCbd
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-0.5-32-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.5
id: hasql-transaction-0.5-5HA6j8NSyfwCLjYw0v64cV
key: hasql-transaction-0.5-5HA6j8NSyfwCLjYw0v64cV
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Queries
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
abi: 164ce0d24794532ae5f0d30e4ef7c3dd
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hasql-transaction-0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/hasql-transaction-0.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/hasql-transaction-0.5
hs-libraries: HShasql-transaction-0.5-5HA6j8NSyfwCLjYw0v64cV
depends:
    base-4.9.0.0 base-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
    bytestring-0.10.8.1
    bytestring-tree-builder-0.2.7.1-E2ysOXo3HB01TL1PzBXA2X
    contravariant-1.4-BhMeiKXigEF6jqFehOEdeG
    contravariant-extras-0.3.3.1-6JwLhf1IH33AIT8qu08gpr
    hasql-0.19.18-KSjIeXEAtpXBhd3dh1T75f
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
